import {
  runHookConfigDone,
  runHookConfigSetup,
  runHookServerSetup,
  runHookServerStart
} from "../../integrations/index.js";
import { createVite } from "../create-vite.js";
import { nodeLogDestination } from "../logger/node.js";
import nodeFs from "fs";
import * as vite from "vite";
import { createDefaultDevSettings } from "../config/index.js";
import { apply as applyPolyfill } from "../polyfill.js";
const defaultLogging = {
  dest: nodeLogDestination,
  level: "error"
};
async function createContainer(params = {}) {
  let {
    isRestart = false,
    logging = defaultLogging,
    settings = await createDefaultDevSettings(params.userConfig, params.root),
    fs = nodeFs
  } = params;
  applyPolyfill();
  settings = await runHookConfigSetup({
    settings,
    command: "dev",
    logging,
    isRestart
  });
  const { host } = settings.config.server;
  const rendererClientEntries = settings.renderers.map((r) => r.clientEntrypoint).filter(Boolean);
  const viteConfig = await createVite(
    {
      mode: "development",
      server: { host },
      optimizeDeps: {
        include: rendererClientEntries
      },
      define: {
        "import.meta.env.BASE_URL": settings.config.base ? `'${settings.config.base}'` : "undefined"
      }
    },
    { settings, logging, mode: "dev", fs }
  );
  await runHookConfigDone({ settings, logging });
  const viteServer = await vite.createServer(viteConfig);
  runHookServerSetup({ config: settings.config, server: viteServer, logging });
  return {
    fs,
    logging,
    settings,
    viteConfig,
    viteServer,
    handle(req, res) {
      viteServer.middlewares.handle(req, res, Function.prototype);
    },
    close() {
      return viteServer.close();
    }
  };
}
async function startContainer({ settings, viteServer, logging }) {
  const { port } = settings.config.server;
  await viteServer.listen(port);
  const devServerAddressInfo = viteServer.httpServer.address();
  await runHookServerStart({
    config: settings.config,
    address: devServerAddressInfo,
    logging
  });
  return devServerAddressInfo;
}
async function runInContainer(params, callback) {
  const container = await createContainer(params);
  try {
    await callback(container);
  } finally {
    await container.close();
  }
}
export {
  createContainer,
  runInContainer,
  startContainer
};
