import { performance } from "perf_hooks";
import { runHookServerDone } from "../../integrations/index.js";
import { info, warn } from "../logger/core.js";
import * as msg from "../messages.js";
import { createContainer, startContainer } from "./container.js";
async function dev(settings, options) {
  var _a, _b;
  const devStart = performance.now();
  await options.telemetry.record([]);
  const container = await createContainer({
    settings,
    logging: options.logging,
    isRestart: options.isRestart
  });
  const devServerAddressInfo = await startContainer(container);
  const site = settings.config.site ? new URL(settings.config.base, settings.config.site) : void 0;
  info(
    options.logging,
    null,
    msg.serverStart({
      startupTime: performance.now() - devStart,
      resolvedUrls: container.viteServer.resolvedUrls || { local: [], network: [] },
      host: settings.config.server.host,
      site,
      isRestart: options.isRestart
    })
  );
  const currentVersion = "0.0.0-hmr-recovery-20221027125930";
  if (currentVersion.includes("-")) {
    warn(options.logging, null, msg.prerelease({ currentVersion }));
  }
  if (((_b = (_a = container.viteConfig.server) == null ? void 0 : _a.fs) == null ? void 0 : _b.strict) === false) {
    warn(options.logging, null, msg.fsStrictWarning());
  }
  return {
    address: devServerAddressInfo,
    get watcher() {
      return container.viteServer.watcher;
    },
    stop: async () => {
      await container.close();
      await runHookServerDone({ config: settings.config, logging: options.logging });
    }
  };
}
export {
  dev as default
};
